aboutsummaryrefslogtreecommitdiff
path: root/pfinet/linux-src/net/ipv6/icmpv6.c
diff options
context:
space:
mode:
Diffstat (limited to 'pfinet/linux-src/net/ipv6/icmpv6.c')
-rw-r--r--pfinet/linux-src/net/ipv6/icmpv6.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/pfinet/linux-src/net/ipv6/icmpv6.c b/pfinet/linux-src/net/ipv6/icmpv6.c
index f7bebe0a..9d701764 100644
--- a/pfinet/linux-src/net/ipv6/icmpv6.c
+++ b/pfinet/linux-src/net/ipv6/icmpv6.c
@@ -567,15 +567,15 @@ int icmpv6_rcv(struct sk_buff *skb, unsigned long len)
default:
if (net_ratelimit())
- printk(KERN_DEBUG "icmpv6: msg of unkown type\n");
+ printk(KERN_DEBUG "icmpv6: msg of unknown type\n");
/* informational */
if (type & 0x80)
break;
/*
* error of unkown type.
* must pass to upper level
*/
icmpv6_notify(skb, type, hdr->icmp6_code, hdr->icmp6_mtu,
@@ -567,15 +567,15 @@ int icmpv6_rcv(struct sk_buff *skb, unsigned long len)
if (type & 0x80)
break;
- /*
- * error of unkown type.
- * must pass to upper level
+ /*
+ * error of unknown type.
+ * must pass to upper level
*/
icmpv6_notify(skb, type, hdr->icmp6_code, hdr->icmp6_mtu,